@@ -21,7 +21,6 @@ const RECYCLER_SHRINK_WINDOW: usize = 16384;
 #[derive(Debug, Default)]
 struct RecyclerStats {
     total: AtomicUsize,
-    freed: AtomicUsize,
     reuse: AtomicUsize,
     max_gc: AtomicUsize,
 }
@@ -183,7 +182,7 @@ impl<T: Default + Reset> RecyclerX<T> {
 
 #[cfg(test)]
 mod tests {
-    use {super::*, crate::packet::PacketBatchRecycler, std::iter::repeat_with};
+    use {super::*, crate::packet::PacketsRecycler, std::iter::repeat_with};
 
     impl Reset for u64 {
         fn reset(&mut self) {
@@ -210,7 +209,7 @@ mod tests {
     #[test]
     fn test_recycler_shrink() {
         let mut rng = rand::thread_rng();
-        let recycler = PacketBatchRecycler::default();
+        let recycler = PacketsRecycler::default();
         // Allocate a burst of packets.
         const NUM_PACKETS: usize = RECYCLER_SHRINK_SIZE * 2;
         {
