@@ -9,22 +9,20 @@ use solana_sdk::transaction::Transaction;
 use {
     crate::{
         cuda_runtime::PinnedVec,
-        packet::{Packet, PacketBatch},
+        packet::{Packet, Packets},
         perf_libs,
         recycler::Recycler,
     },
-    ahash::AHasher,
-    rand::{thread_rng, Rng},
     rayon::ThreadPool,
     solana_metrics::inc_new_counter_debug,
     solana_rayon_threadlimit::get_thread_count,
     solana_sdk::{
-        hash::Hash, message::MESSAGE_HEADER_LENGTH, pubkey::Pubkey, short_vec::decode_shortu16_len,
+        hash::Hash,
+        message::{MESSAGE_HEADER_LENGTH, MESSAGE_VERSION_PREFIX},
+        pubkey::Pubkey,
+        short_vec::decode_shortu16_len,
         signature::Signature,
     },
-    std::hash::Hasher,
-    std::sync::atomic::{AtomicBool, AtomicU64, Ordering},
-    std::time::{Duration, Instant},
     std::{convert::TryFrom, mem::size_of},
 };
 
@@ -84,6 +82,7 @@ pub enum PacketError {
     PayerNotWritable,
     InvalidProgramIdIndex,
     InvalidProgramLen,
+    UnsupportedVersion,
 }
 
 impl std::convert::From<std::boxed::Box<bincode::ErrorKind>> for PacketError {
@@ -102,25 +101,23 @@ pub fn init() {
     if let Some(api) = perf_libs::api() {
         unsafe {
             (api.ed25519_set_verbose)(true);
-            if !(api.ed25519_init)() {
-                panic!("ed25519_init() failed");
-            }
+            assert!((api.ed25519_init)(), "ed25519_init() failed");
             (api.ed25519_set_verbose)(false);
         }
     }
 }
 
 fn verify_packet(packet: &mut Packet, reject_non_vote: bool) {
-    // If this packet was already marked as discard, drop it
-    if packet.meta.discard {
-        return;
-    }
-
     let packet_offsets = get_packet_offsets(packet, 0, reject_non_vote);
     let mut sig_start = packet_offsets.sig_start as usize;
     let mut pubkey_start = packet_offsets.pubkey_start as usize;
     let msg_start = packet_offsets.msg_start as usize;
 
+    // If this packet was already marked as discard, drop it
+    if packet.meta.discard {
+        return;
+    }
+
     if packet_offsets.sig_len == 0 {
         packet.meta.discard = true;
         return;
@@ -161,8 +158,8 @@ fn verify_packet(packet: &mut Packet, reject_non_vote: bool) {
     }
 }
 
-pub fn count_packets_in_batches(batches: &[PacketBatch]) -> usize {
-    batches.iter().map(|batch| batch.packets.len()).sum()
+pub fn batch_size(batches: &[Packets]) -> usize {
+    batches.iter().map(|p| p.packets.len()).sum()
 }
 
 // internal function to be unit-tested; should be used only by get_packet_offsets
@@ -170,10 +167,9 @@ fn do_get_packet_offsets(
     packet: &Packet,
     current_offset: usize,
 ) -> Result<PacketOffsets, PacketError> {
-    // should have at least 1 signature, sig lengths and the message header
+    // should have at least 1 signature and sig lengths
     let _ = 1usize
         .checked_add(size_of::<Signature>())
-        .and_then(|v| v.checked_add(MESSAGE_HEADER_LENGTH))
         .filter(|v| *v <= packet.meta.size)
         .ok_or(PacketError::InvalidLen)?;
 
@@ -188,28 +184,57 @@ fn do_get_packet_offsets(
         .and_then(|v| v.checked_add(sig_size))
         .ok_or(PacketError::InvalidLen)?;
 
-    let msg_start_offset_plus_one = msg_start_offset
+    // Determine the start of the message header by checking the message prefix bit.
+    let msg_header_offset = {
+        // Packet should have data for prefix bit
+        if msg_start_offset >= packet.meta.size {
+            return Err(PacketError::InvalidSignatureLen);
+        }
+
+        // next byte indicates if the transaction is versioned. If the top bit
+        // is set, the remaining bits encode a version number. If the top bit is
+        // not set, this byte is the first byte of the message header.
+        let message_prefix = packet.data[msg_start_offset];
+        if message_prefix & MESSAGE_VERSION_PREFIX != 0 {
+            let version = message_prefix & !MESSAGE_VERSION_PREFIX;
+            match version {
+                0 => {
+                    // header begins immediately after prefix byte
+                    msg_start_offset
+                        .checked_add(1)
+                        .ok_or(PacketError::InvalidLen)?
+                }
+
+                // currently only v0 is supported
+                _ => return Err(PacketError::UnsupportedVersion),
+            }
+        } else {
+            msg_start_offset
+        }
+    };
+
+    let msg_header_offset_plus_one = msg_header_offset
         .checked_add(1)
         .ok_or(PacketError::InvalidLen)?;
 
-    // Packet should have data at least for signatures, MessageHeader, 1 byte for Message.account_keys.len
-    let _ = msg_start_offset_plus_one
+    // Packet should have data at least for MessageHeader and 1 byte for Message.account_keys.len
+    let _ = msg_header_offset_plus_one
         .checked_add(MESSAGE_HEADER_LENGTH)
         .filter(|v| *v <= packet.meta.size)
         .ok_or(PacketError::InvalidSignatureLen)?;
 
     // read MessageHeader.num_required_signatures (serialized with u8)
-    let sig_len_maybe_trusted = packet.data[msg_start_offset];
+    let sig_len_maybe_trusted = packet.data[msg_header_offset];
 
-    let message_account_keys_len_offset = msg_start_offset
+    let message_account_keys_len_offset = msg_header_offset
         .checked_add(MESSAGE_HEADER_LENGTH)
-        .ok_or(PacketError::InvalidLen)?;
+        .ok_or(PacketError::InvalidSignatureLen)?;
 
     // This reads and compares the MessageHeader num_required_signatures and
     // num_readonly_signed_accounts bytes. If num_required_signatures is not larger than
     // num_readonly_signed_accounts, the first account is not debitable, and cannot be charged
     // required transaction fees.
-    let readonly_signer_offset = msg_start_offset_plus_one;
+    let readonly_signer_offset = msg_header_offset_plus_one;
     if sig_len_maybe_trusted <= packet.data[readonly_signer_offset] {
         return Err(PacketError::PayerNotWritable);
     }
@@ -341,7 +366,7 @@ fn check_for_simple_vote_transaction(
 }
 
 pub fn generate_offsets(
-    batches: &mut [PacketBatch],
+    batches: &mut [Packets],
     recycler: &Recycler<TxOffset>,
     reject_non_vote: bool,
 ) -> TxOffsets {
@@ -356,9 +381,9 @@ pub fn generate_offsets(
     msg_sizes.set_pinnable();
     let mut current_offset: usize = 0;
     let mut v_sig_lens = Vec::new();
-    batches.iter_mut().for_each(|batch| {
+    batches.iter_mut().for_each(|p| {
         let mut sig_lens = Vec::new();
-        batch.packets.iter_mut().for_each(|packet| {
+        p.packets.iter_mut().for_each(|packet| {
             let packet_offsets = get_packet_offsets(packet, current_offset, reject_non_vote);
 
             sig_lens.push(packet_offsets.sig_len);
@@ -393,101 +418,30 @@ pub fn generate_offsets(
     )
 }
 
-pub struct Deduper {
-    filter: Vec<AtomicU64>,
-    seed: (u128, u128),
-    age: Instant,
-    max_age: Duration,
-    pub saturated: AtomicBool,
-}
-
-impl Deduper {
-    pub fn new(size: u32, max_age: Duration) -> Self {
-        let mut filter: Vec<AtomicU64> = Vec::with_capacity(size as usize);
-        filter.resize_with(size as usize, Default::default);
-        let seed = thread_rng().gen();
-        Self {
-            filter,
-            seed,
-            age: Instant::now(),
-            max_age,
-            saturated: AtomicBool::new(false),
-        }
-    }
-
-    pub fn reset(&mut self) {
-        let now = Instant::now();
-        //this should reset every 500k unique packets per 1m sized deduper
-        //false positive rate is 1/1000 at that point
-        let saturated = self.saturated.load(Ordering::Relaxed);
-        if saturated || now.duration_since(self.age) > self.max_age {
-            for i in &self.filter {
-                i.store(0, Ordering::Relaxed);
-            }
-            self.seed = thread_rng().gen();
-            self.age = now;
-            self.saturated.store(false, Ordering::Relaxed);
-        }
-    }
-
-    fn dedup_packet(&self, packet: &mut Packet) -> u64 {
-        // If this packet was already marked as discard, drop it
-        if packet.meta.discard {
-            return 0;
-        }
-        let mut hasher = AHasher::new_with_keys(self.seed.0, self.seed.1);
-        hasher.write(&packet.data[0..packet.meta.size]);
-        let hash = hasher.finish();
-        let len = self.filter.len();
-        let pos = (usize::try_from(hash).unwrap()).wrapping_rem(len);
-        // saturate each position with or
-        let prev = self.filter[pos].fetch_or(hash, Ordering::Relaxed);
-        if prev == u64::MAX {
-            self.saturated.store(true, Ordering::Relaxed);
-            //reset this value
-            self.filter[pos].store(hash, Ordering::Relaxed);
-        }
-        if hash == prev & hash {
-            packet.meta.discard = true;
-            return 1;
-        }
-        0
-    }
-
-    pub fn dedup_packets(&self, batches: &mut [PacketBatch]) -> u64 {
-        batches
-            .iter_mut()
-            .flat_map(|batch| batch.packets.iter_mut().map(|p| self.dedup_packet(p)))
-            .sum()
-    }
-}
-
-pub fn ed25519_verify_cpu(batches: &mut [PacketBatch], reject_non_vote: bool) {
+pub fn ed25519_verify_cpu(batches: &mut [Packets], reject_non_vote: bool) {
     use rayon::prelude::*;
-    let packet_count = count_packets_in_batches(batches);
-    debug!("CPU ECDSA for {}", packet_count);
+    let count = batch_size(batches);
+    debug!("CPU ECDSA for {}", batch_size(batches));
     PAR_THREAD_POOL.install(|| {
-        batches.into_par_iter().for_each(|batch| {
-            batch
-                .packets
+        batches.into_par_iter().for_each(|p| {
+            p.packets
                 .par_iter_mut()
                 .for_each(|p| verify_packet(p, reject_non_vote))
-        });
+        })
     });
-    inc_new_counter_debug!("ed25519_verify_cpu", packet_count);
+    inc_new_counter_debug!("ed25519_verify_cpu", count);
 }
 
-pub fn ed25519_verify_disabled(batches: &mut [PacketBatch]) {
+pub fn ed25519_verify_disabled(batches: &mut [Packets]) {
     use rayon::prelude::*;
-    let packet_count = count_packets_in_batches(batches);
-    debug!("disabled ECDSA for {}", packet_count);
-    batches.into_par_iter().for_each(|batch| {
-        batch
-            .packets
+    let count = batch_size(batches);
+    debug!("disabled ECDSA for {}", batch_size(batches));
+    batches.into_par_iter().for_each(|p| {
+        p.packets
             .par_iter_mut()
             .for_each(|p| p.meta.discard = false)
     });
-    inc_new_counter_debug!("ed25519_verify_disabled", packet_count);
+    inc_new_counter_debug!("ed25519_verify_disabled", count);
 }
 
 pub fn copy_return_values(sig_lens: &[Vec<u32>], out: &PinnedVec<u8>, rvs: &mut Vec<Vec<u8>>) {
@@ -541,7 +495,7 @@ pub fn get_checked_scalar(scalar: &[u8; 32]) -> Result<[u8; 32], PacketError> {
     Ok(out)
 }
 
-pub fn mark_disabled(batches: &mut [PacketBatch], r: &[Vec<u8>]) {
+pub fn mark_disabled(batches: &mut [Packets], r: &[Vec<u8>]) {
     batches.iter_mut().zip(r).for_each(|(b, v)| {
         b.packets.iter_mut().zip(v).for_each(|(p, f)| {
             p.meta.discard = *f == 0;
@@ -550,7 +504,7 @@ pub fn mark_disabled(batches: &mut [PacketBatch], r: &[Vec<u8>]) {
 }
 
 pub fn ed25519_verify(
-    batches: &mut [PacketBatch],
+    batches: &mut [Packets],
     recycler: &Recycler<TxOffset>,
     recycler_out: &Recycler<PinnedVec<u8>>,
     reject_non_vote: bool,
@@ -562,21 +516,21 @@ pub fn ed25519_verify(
     let api = api.unwrap();
 
     use crate::packet::PACKET_DATA_SIZE;
-    let packet_count = count_packets_in_batches(batches);
+    let count = batch_size(batches);
 
     // micro-benchmarks show GPU time for smallest batch around 15-20ms
     // and CPU speed for 64-128 sigverifies around 10-20ms. 64 is a nice
     // power-of-two number around that accounting for the fact that the CPU
     // may be busy doing other things while being a real validator
     // TODO: dynamically adjust this crossover
-    if packet_count < 64 {
+    if count < 64 {
         return ed25519_verify_cpu(batches, reject_non_vote);
     }
 
     let (signature_offsets, pubkey_offsets, msg_start_offsets, msg_sizes, sig_lens) =
         generate_offsets(batches, recycler, reject_non_vote);
 
-    debug!("CUDA ECDSA for {}", packet_count);
+    debug!("CUDA ECDSA for {}", batch_size(batches));
     debug!("allocating out..");
     let mut out = recycler_out.allocate("out_buffer");
     out.set_pinnable();
@@ -584,15 +538,15 @@ pub fn ed25519_verify(
     let mut rvs = Vec::new();
 
     let mut num_packets: usize = 0;
-    for batch in batches.iter() {
+    for p in batches.iter() {
         elems.push(perf_libs::Elems {
-            elems: batch.packets.as_ptr(),
-            num: batch.packets.len() as u32,
+            elems: p.packets.as_ptr(),
+            num: p.packets.len() as u32,
         });
         let mut v = Vec::new();
-        v.resize(batch.packets.len(), 0);
+        v.resize(p.packets.len(), 0);
         rvs.push(v);
-        num_packets = num_packets.saturating_add(batch.packets.len());
+        num_packets = num_packets.saturating_add(p.packets.len());
     }
     out.resize(signature_offsets.len(), 0);
     trace!("Starting verify num packets: {}", num_packets);
@@ -621,7 +575,7 @@ pub fn ed25519_verify(
     trace!("done verify");
     copy_return_values(&sig_lens, &out, &mut rvs);
     mark_disabled(batches, &rvs);
-    inc_new_counter_debug!("ed25519_verify_gpu", packet_count);
+    inc_new_counter_debug!("ed25519_verify_gpu", count);
 }
 
 #[cfg(test)]
@@ -641,7 +595,7 @@ mod tests {
     use {
         super::*,
         crate::{
-            packet::{to_packet_batches, Packet, PacketBatch},
+            packet::{Packet, Packets},
             sigverify::{self, PacketOffsets},
             test_tx::{test_multisig_tx, test_tx, vote_tx},
         },
@@ -669,9 +623,9 @@ mod tests {
 
     #[test]
     fn test_mark_disabled() {
-        let mut batch = PacketBatch::default();
+        let mut batch = Packets::default();
         batch.packets.push(Packet::default());
-        let mut batches: Vec<PacketBatch> = vec![batch];
+        let mut batches: Vec<Packets> = vec![batch];
         mark_disabled(&mut batches, &[vec![0]]);
         assert!(batches[0].packets[0].meta.discard);
         mark_disabled(&mut batches, &[vec![1]]);
@@ -746,22 +700,6 @@ mod tests {
         );
     }
 
-    #[test]
-    fn test_large_sigs() {
-        // use any large number to be misinterpreted as 2 bytes when decoded as short_vec
-        let required_num_sigs = 214;
-        let actual_num_sigs = 5;
-
-        let packet = packet_from_num_sigs(required_num_sigs, actual_num_sigs);
-
-        let unsanitized_packet_offsets = sigverify::do_get_packet_offsets(&packet, 0);
-
-        assert_eq!(
-            unsanitized_packet_offsets,
-            Err(PacketError::MismatchSignatureLen)
-        );
-    }
-
     #[test]
     fn test_small_packet() {
         let tx = test_tx();
@@ -793,7 +731,7 @@ mod tests {
         assert!(packet.meta.discard);
 
         packet.meta.discard = false;
-        let mut batches = generate_packet_batches(&packet, 1, 1);
+        let mut batches = generate_packet_vec(&packet, 1, 1);
         ed25519_verify(&mut batches);
         assert!(batches[0].packets[0].meta.discard);
     }
@@ -812,7 +750,7 @@ mod tests {
         message.account_keys.push(pubkey1);
         message.account_keys.push(pubkey1);
         message.header.num_required_signatures = NUM_SIG as u8;
-        message.recent_blockhash = Hash(pubkey1.to_bytes());
+        message.recent_blockhash = Hash::new_from_array(pubkey1.to_bytes());
         let mut tx = Transaction::new_unsigned(message);
 
         info!("message: {:?}", tx.message_data());
@@ -829,7 +767,7 @@ mod tests {
         assert!(packet.meta.discard);
 
         packet.meta.discard = false;
-        let mut batches = generate_packet_batches(&packet, 1, 1);
+        let mut batches = generate_packet_vec(&packet, 1, 1);
         ed25519_verify(&mut batches);
         assert!(batches[0].packets[0].meta.discard);
     }
@@ -895,6 +833,43 @@ mod tests {
         assert_eq!(res, Err(PacketError::PayerNotWritable));
     }
 
+    #[test]
+    fn test_unsupported_version() {
+        let tx = test_tx();
+        let mut packet = sigverify::make_packet_from_transaction(tx);
+
+        let res = sigverify::do_get_packet_offsets(&packet, 0);
+
+        // set message version to 1
+        packet.data[res.unwrap().msg_start as usize] = MESSAGE_VERSION_PREFIX + 1;
+
+        let res = sigverify::do_get_packet_offsets(&packet, 0);
+        assert_eq!(res, Err(PacketError::UnsupportedVersion));
+    }
+
+    #[test]
+    fn test_versioned_message() {
+        let tx = test_tx();
+        let mut packet = sigverify::make_packet_from_transaction(tx);
+
+        let mut legacy_offsets = sigverify::do_get_packet_offsets(&packet, 0).unwrap();
+
+        // set message version to 0
+        let msg_start = legacy_offsets.msg_start as usize;
+        let msg_bytes = packet.data[msg_start..packet.meta.size].to_vec();
+        packet.data[msg_start] = MESSAGE_VERSION_PREFIX;
+        packet.meta.size += 1;
+        packet.data[msg_start + 1..packet.meta.size].copy_from_slice(&msg_bytes);
+
+        let offsets = sigverify::do_get_packet_offsets(&packet, 0).unwrap();
+        let expected_offsets = {
+            legacy_offsets.pubkey_start += 1;
+            legacy_offsets
+        };
+
+        assert_eq!(expected_offsets, offsets);
+    }
+
     #[test]
     fn test_system_transaction_data_layout() {
         use crate::packet::PACKET_DATA_SIZE;
@@ -954,21 +929,21 @@ mod tests {
         );
     }
 
-    fn generate_packet_batches(
+    fn generate_packet_vec(
         packet: &Packet,
         num_packets_per_batch: usize,
         num_batches: usize,
-    ) -> Vec<PacketBatch> {
+    ) -> Vec<Packets> {
         // generate packet vector
         let batches: Vec<_> = (0..num_batches)
             .map(|_| {
-                let mut packet_batch = PacketBatch::default();
-                packet_batch.packets.resize(0, Packet::default());
+                let mut packets = Packets::default();
+                packets.packets.resize(0, Packet::default());
                 for _ in 0..num_packets_per_batch {
-                    packet_batch.packets.push(packet.clone());
+                    packets.packets.push(packet.clone());
                 }
-                assert_eq!(packet_batch.packets.len(), num_packets_per_batch);
-                packet_batch
+                assert_eq!(packets.packets.len(), num_packets_per_batch);
+                packets
             })
             .collect();
         assert_eq!(batches.len(), num_batches);
@@ -985,7 +960,7 @@ mod tests {
             packet.data[20] = packet.data[20].wrapping_add(10);
         }
 
-        let mut batches = generate_packet_batches(&packet, n, 2);
+        let mut batches = generate_packet_vec(&packet, n, 2);
 
         // verify packets
         ed25519_verify(&mut batches);
@@ -994,11 +969,11 @@ mod tests {
         let should_discard = modify_data;
         assert!(batches
             .iter()
-            .flat_map(|batch| &batch.packets)
+            .flat_map(|p| &p.packets)
             .all(|p| p.meta.discard == should_discard));
     }
 
-    fn ed25519_verify(batches: &mut [PacketBatch]) {
+    fn ed25519_verify(batches: &mut [Packets]) {
         let recycler = Recycler::default();
         let recycler_out = Recycler::default();
         sigverify::ed25519_verify(batches, &recycler, &recycler_out, false);
@@ -1011,13 +986,13 @@ mod tests {
         tx.signatures.pop();
         let packet = sigverify::make_packet_from_transaction(tx);
 
-        let mut batches = generate_packet_batches(&packet, 1, 1);
+        let mut batches = generate_packet_vec(&packet, 1, 1);
 
         // verify packets
         ed25519_verify(&mut batches);
         assert!(batches
             .iter()
-            .flat_map(|batch| &batch.packets)
+            .flat_map(|p| &p.packets)
             .all(|p| p.meta.discard));
     }
 
@@ -1045,7 +1020,7 @@ mod tests {
 
         let n = 4;
         let num_batches = 3;
-        let mut batches = generate_packet_batches(&packet, n, num_batches);
+        let mut batches = generate_packet_vec(&packet, n, num_batches);
 
         packet.data[40] = packet.data[40].wrapping_add(8);
 
@@ -1060,7 +1035,7 @@ mod tests {
         ref_vec[0].push(0u8);
         assert!(batches
             .iter()
-            .flat_map(|batch| &batch.packets)
+            .flat_map(|p| &p.packets)
             .zip(ref_vec.into_iter().flatten())
             .all(|(p, discard)| {
                 if discard == 0 {
@@ -1084,7 +1059,7 @@ mod tests {
         for _ in 0..50 {
             let n = thread_rng().gen_range(1, 30);
             let num_batches = thread_rng().gen_range(2, 30);
-            let mut batches = generate_packet_batches(&packet, n, num_batches);
+            let mut batches = generate_packet_vec(&packet, n, num_batches);
 
             let num_modifications = thread_rng().gen_range(0, 5);
             for _ in 0..num_modifications {
@@ -1105,8 +1080,8 @@ mod tests {
             // check result
             batches
                 .iter()
-                .flat_map(|batch| &batch.packets)
-                .zip(batches_cpu.iter().flat_map(|batch| &batch.packets))
+                .flat_map(|p| &p.packets)
+                .zip(batches_cpu.iter().flat_map(|p| &p.packets))
                 .for_each(|(p1, p2)| assert_eq!(p1, p2));
         }
     }
@@ -1258,7 +1233,7 @@ mod tests {
         solana_logger::setup();
 
         let mut current_offset = 0usize;
-        let mut batch = PacketBatch::default();
+        let mut batch = Packets::default();
         batch
             .packets
             .push(sigverify::make_packet_from_transaction(test_tx()));
@@ -1269,10 +1244,9 @@ mod tests {
             .packets
             .iter_mut()
             .enumerate()
-            .for_each(|(index, mut packet)| {
-                let packet_offsets = do_get_packet_offsets(&packet, current_offset).unwrap();
-                check_for_simple_vote_transaction(&mut packet, &packet_offsets, current_offset)
-                    .ok();
+            .for_each(|(index, packet)| {
+                let packet_offsets = do_get_packet_offsets(packet, current_offset).unwrap();
+                check_for_simple_vote_transaction(packet, &packet_offsets, current_offset).ok();
                 if index == 1 {
                     assert!(packet.meta.is_simple_vote_tx);
                 } else {
@@ -1282,62 +1256,4 @@ mod tests {
                 current_offset = current_offset.saturating_add(size_of::<Packet>());
             });
     }
-
-    #[test]
-    fn test_dedup_same() {
-        let tx = test_tx();
-
-        let mut batches =
-            to_packet_batches(&std::iter::repeat(tx).take(1024).collect::<Vec<_>>(), 128);
-        let packet_count = sigverify::count_packets_in_batches(&batches);
-        let filter = Deduper::new(1_000_000, Duration::from_millis(0));
-        let discard = filter.dedup_packets(&mut batches) as usize;
-        assert_eq!(packet_count, discard + 1);
-    }
-
-    #[test]
-    fn test_dedup_diff() {
-        let mut filter = Deduper::new(1_000_000, Duration::from_millis(0));
-        let mut batches = to_packet_batches(&(0..1024).map(|_| test_tx()).collect::<Vec<_>>(), 128);
-
-        let discard = filter.dedup_packets(&mut batches) as usize;
-        // because dedup uses a threadpool, there maybe up to N threads of txs that go through
-        assert_eq!(discard, 0);
-        filter.reset();
-        for i in filter.filter {
-            assert_eq!(i.load(Ordering::Relaxed), 0);
-        }
-    }
-
-    #[test]
-    #[ignore]
-    fn test_dedup_saturated() {
-        let filter = Deduper::new(1_000_000, Duration::from_millis(0));
-        let mut discard = 0;
-        assert!(!filter.saturated.load(Ordering::Relaxed));
-        for i in 0..1000 {
-            let mut batches =
-                to_packet_batches(&(0..1000).map(|_| test_tx()).collect::<Vec<_>>(), 128);
-            discard += filter.dedup_packets(&mut batches) as usize;
-            println!("{} {}", i, discard);
-            if filter.saturated.load(Ordering::Relaxed) {
-                break;
-            }
-        }
-        assert!(filter.saturated.load(Ordering::Relaxed));
-    }
-
-    #[test]
-    fn test_dedup_false_positive() {
-        let filter = Deduper::new(1_000_000, Duration::from_millis(0));
-        let mut discard = 0;
-        for i in 0..10 {
-            let mut batches =
-                to_packet_batches(&(0..1024).map(|_| test_tx()).collect::<Vec<_>>(), 128);
-            discard += filter.dedup_packets(&mut batches) as usize;
-            println!("false positive rate: {}/{}", discard, i * 1024);
-        }
-        //allow for 1 false positive even if extremely unlikely
-        assert!(discard < 2);
-    }
 }
